@@ -6,9 +6,9 @@ Type annotations for docdb service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_docdb.literals import ApplyMethod
+    from mypy_boto3_docdb.literals import ApplyMethodType
 
-    data: ApplyMethod = "immediate"
+    data: ApplyMethodType = "immediate"
     ```
 """
 import sys
@@ -20,7 +20,7 @@ else:
 
 
 __all__ = (
-    "ApplyMethod",
+    "ApplyMethodType",
     "DBInstanceAvailableWaiterName",
     "DBInstanceDeletedWaiterName",
     "DescribeCertificatesPaginatorName",
@@ -35,11 +35,11 @@ __all__ = (
     "DescribeEventsPaginatorName",
     "DescribeOrderableDBInstanceOptionsPaginatorName",
     "DescribePendingMaintenanceActionsPaginatorName",
-    "SourceType",
+    "SourceTypeType",
 )
 
 
-ApplyMethod = Literal["immediate", "pending-reboot"]
+ApplyMethodType = Literal["immediate", "pending-reboot"]
 DBInstanceAvailableWaiterName = Literal["db_instance_available"]
 DBInstanceDeletedWaiterName = Literal["db_instance_deleted"]
 DescribeCertificatesPaginatorName = Literal["describe_certificates"]
@@ -54,7 +54,7 @@ DescribeEventSubscriptionsPaginatorName = Literal["describe_event_subscriptions"
 DescribeEventsPaginatorName = Literal["describe_events"]
 DescribeOrderableDBInstanceOptionsPaginatorName = Literal["describe_orderable_db_instance_options"]
 DescribePendingMaintenanceActionsPaginatorName = Literal["describe_pending_maintenance_actions"]
-SourceType = Literal[
+SourceTypeType = Literal[
     "db-cluster",
     "db-cluster-snapshot",
     "db-instance",
