@@ -15,7 +15,7 @@ import sys
 from datetime import datetime
 from typing import List
 
-from .literals import ApplyMethod, SourceType
+from .literals import ApplyMethodType, SourceTypeType
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -587,7 +587,7 @@ EventTypeDef = TypedDict(
     "EventTypeDef",
     {
         "SourceIdentifier": str,
-        "SourceType": SourceType,
+        "SourceType": SourceTypeType,
         "Message": str,
         "EventCategories": List[str],
         "Date": datetime,
@@ -705,7 +705,7 @@ ParameterTypeDef = TypedDict(
         "AllowedValues": str,
         "IsModifiable": bool,
         "MinimumEngineVersion": str,
-        "ApplyMethod": ApplyMethod,
+        "ApplyMethod": ApplyMethodType,
     },
     total=False,
 )
